Token.Texts and Numbers
#######################

TextToken
*********

.. autoclass:: miniworldmaker.tokens.text_token.TextToken
   :members:


NumberToken
***********

.. autoclass:: miniworldmaker.tokens.number_token.NumberToken
   :members: